@@ -1,9 +1,9 @@
-from green.plugin import Green
 from green.cmdline import main
+from green.runner import GreenTestRunner
 from green.version import __version__
 
 
 # So pyflakes will stop complaining about disuse...
-Green
+GreenTestRunner
 main
 __version__
